﻿package de.davidochmann.games.crashlines 
{
	/**
	 * @author dochmann
	 */
	
	import com.greensock.TweenMax;		
	import flash.display.Stage;	 
	import flash.filters.BlurFilter;	
	import flash.filters.DropShadowFilter;	
	import flash.geom.Point;	
	import flash.geom.Rectangle;	
	import flash.events.KeyboardEvent;	
	import flash.events.Event;	
	import flash.display.BitmapData;	
	import flash.display.Bitmap;	
	import flash.display.Sprite;

	public class Game extends Sprite 
	{
		public static var GRAPHIC_LOW:uint = 1;
		public static var GRAPHIC_HIGH:uint = 2;
		
		private static var NULL_POINT:Point = new Point(0, 0);
		private static var PLAYER_SIZE:uint = 4;
		private static var PLAYER_SPEED:uint = 5;
		
		private var mStage:Stage;
		private var mGameWidth:uint;
		private var mGameHeight:uint;
		private var mGameGraphic:uint;
		
		private var mXDirectionPlayer1:int;
		private var mYDirectionPlayer1:int;
		private var mXDirectionPlayer2:int;
		private var mYDirectionPlayer2:int;
		
		private var mControls:Sprite;
		private var mBitmapData:BitmapData;
		private var mBitmapDataCompare:BitmapData;
		private var mBitmapDataBackground:BitmapData;
		private var mClearRectangle:Rectangle;
		private var mBitmap:Bitmap;
		private var mBitmapBackground:Bitmap;
		private var mDropShadow:DropShadowFilter;
		private var mBlur:BlurFilter;

		private var mPlayer1:Sprite;
		private var mPlayer2:Sprite;
		private var mContainer:Sprite;
		private var mPlayerOut:Boolean;
		
		public function Game(pStage:Stage,
									  pGameWidth:uint, 
									  pGameHeight:uint, 
									  pGameGraphic:uint = 1)
		{
			setStage(pStage);
			setGameWidth(pGameWidth);
			setGameHeight(pGameHeight);
			setGameGraphic(pGameGraphic);
			
			initControls();
			initBitmapData();
			initBitmapDataCompare();
			initBitmapDataBackground();
			initClearRectangle();
			initBitmap();
			initBitmapBackground();
			initDropShadow();
			initBlur();
			initPlayer1();
			initPlayer2();
			initPlayerPositions();
			initPlayerDirection();
			initContainer();
			
			addKeyboardEvents();
			addChildren();
			
			initDraw();
		}
		
	
		public function getStage():Stage
		{
			return mStage;
		}

		public function getGameWidth():uint
		{
			return mGameWidth;
		}

		public function getGameHeight():uint
		{
			return mGameHeight;
		}
		
		public function getGameGraphics():uint
		{
			return mGameGraphic;
		}

		
		public function setStage(pStage:Stage):void
		{
			mStage = pStage;
		}

		public function setGameWidth(pGameWidth:uint):void
		{
			mGameWidth = pGameWidth;
		}

		public function setGameHeight(pGameHeight:uint):void
		{
			mGameHeight = pGameHeight;
		}

		public function setGameGraphic(pGameGraphic:uint):void
		{
			mGameGraphic = pGameGraphic;	
		}


		private function addKeyboardEvents():void
		{
			mStage.addEventListener(KeyboardEvent.KEY_DOWN, keyboardKeyDownHandler);			
		}
		
		private function removeKeyboardEvents():void
		{
			mStage.removeEventListener(KeyboardEvent.KEY_DOWN, keyboardKeyDownHandler);	
		}
			
		private function keyboardKeyDownHandler(e:KeyboardEvent):void
		{
			if(! stage.hasEventListener(Event.ENTER_FRAME)) 
				initEnterFrame();
			
			switch(e.keyCode)
			{
				default:
				case 13:
					clearEnterFrame();
					break;
				
				case 38:
					if(mYDirectionPlayer1 != 1)
					{
						mXDirectionPlayer1 =  0;
						mYDirectionPlayer1 = -1;
					}
					break;
					
				case 40:
					if(mYDirectionPlayer1 != -1)
					{
						mXDirectionPlayer1 =  0;
						mYDirectionPlayer1 =  1;
					}
					break;
					
				case 37:
					if(mXDirectionPlayer1 != 1)
					{
						mXDirectionPlayer1 = -1;
						mYDirectionPlayer1 =  0;
					}
					break;
					
				case 39:
					if(mXDirectionPlayer1 != -1)
					{
						mXDirectionPlayer1 =  1;
						mYDirectionPlayer1 =  0;
					}
					break;
					
					
				case 87:
					if(mYDirectionPlayer2 != 1)
					{
						mXDirectionPlayer2 =  0;
						mYDirectionPlayer2 = -1;
					}
					break;
					
				case 83:
					if(mYDirectionPlayer2 != -1)
					{
						mXDirectionPlayer2 =  0;
						mYDirectionPlayer2 =  1;
					}
					break;
					
				case 65:
					if(mXDirectionPlayer2 != 1)
					{
						mXDirectionPlayer2 = -1;
						mYDirectionPlayer2 =  0;
					}
					break;
					
				case 68:
					if(mXDirectionPlayer2 != -1)
					{
						mXDirectionPlayer2 =  1;
						mYDirectionPlayer2 =  0;
					}
					break;
			}
		}

		
		private function initControls():void
		{
			mControls = new Sprite();
			
//			var background:Sprite = GraphicContainer.getInstance().mControlsBackground;
			var player1:Sprite = GraphicContainer.getInstance().mControlsPlayer1;
			var player2:Sprite = GraphicContainer.getInstance().mControlsPlayer2;
			var pause:Sprite = GraphicContainer.getInstance().mControlsPause;

//			background.x = mGameWidth * .5 - background.width * .5;
//			background.y = mGameHeight - background.height - 20;
			
			player2.x = 200;
			player2.y = mGameHeight - 70;
			
			player1.x = mGameWidth - 200 - player2.width;
			player1.y = mGameHeight - 70;
			
			pause.x = mGameWidth * .5 - pause.width * .5;
			pause.y = mGameHeight - 70;
			
//			mControls.addChild(background);
			mControls.addChild(player1);
			mControls.addChild(player2);
			mControls.addChild(pause);
		}

		private function initBitmapData():void
		{
			mBitmapData = new BitmapData(mGameWidth, mGameHeight, true, 0xffffff);
		}
		
		private function clearBitmapData():void
		{
			mBitmapData.fillRect(mClearRectangle, 0);
		}
		
		private function initBitmapDataCompare():void
		{
			mBitmapDataCompare = new BitmapData(mGameWidth, mGameHeight, true, 0xffffff); 
		}
		
		private function initBitmapDataBackground():void
		{
			mBitmapDataBackground = new BitmapData(mGameWidth, mGameHeight, true, 0xffffff);
		}

		private function clearBitmapDataBackground():void
		{
			mBitmapDataBackground.fillRect(mClearRectangle, 0);
		}

		private function initClearRectangle():void
		{
			mClearRectangle = new Rectangle(0, 0, mGameWidth, mGameHeight);
		}

		private function initBitmap():void
		{
			mBitmap = new Bitmap(mBitmapData, "auto", false);			
		}
		
		private function initBitmapBackground():void
		{
			mBitmapBackground = new Bitmap(mBitmapDataBackground, "auto", false);
		}

		private function initDropShadow():void
		{
			mDropShadow = new DropShadowFilter(0, 45, 0x000000, .8, 6, 6, .8, 1, false, false, false);
		}

		private function initBlur():void
		{
			mBlur = new BlurFilter(6, 6, 1);
		}

		private function initPlayer1():void
		{
			mPlayer1 = new Sprite();
			
			mPlayer1.graphics.beginFill(0xff0000);
			mPlayer1.graphics.drawRect(-PLAYER_SIZE * .5, -PLAYER_SIZE * .5, PLAYER_SIZE, PLAYER_SIZE);
			mPlayer1.graphics.endFill();
		}

		private function initPlayer2():void
		{
			mPlayer2 = new Sprite();
			
			mPlayer2.graphics.beginFill(0x0000ff);
			mPlayer2.graphics.drawRect(-PLAYER_SIZE * .5, -PLAYER_SIZE * .5, PLAYER_SIZE, PLAYER_SIZE);
			mPlayer2.graphics.endFill();
		}

		private function initPlayerDirection():void
		{
			mXDirectionPlayer1 =  1;
			mYDirectionPlayer1 =  0;			
			
			mXDirectionPlayer2 = -1;
			mYDirectionPlayer2 =  0;
		}

		private function initPlayerPositions():void
		{
			mPlayer1.x = Math.floor(mGameWidth * .5 + 10);
			mPlayer1.y = Math.floor(mGameHeight * .5);	
			mPlayer2.x = Math.floor(mGameWidth * .5 - 10);
			mPlayer2.y = Math.floor(mGameHeight * .5);
		}

		private function initContainer():void
		{
			mContainer = new Sprite();
			mContainer.addChild(mPlayer1);
			mContainer.addChild(mPlayer2);
		}

		
		private function initDraw():void
		{
			switch(mGameGraphic)
			{
				case GRAPHIC_LOW:
					enterFrameLowGraphic();
					break;
					
				case GRAPHIC_HIGH:
					enterFrameHighGraphic();
					break;
			}
		}
		
		private function initEnterFrame():void
		{
			switch(mGameGraphic)
			{
				case GRAPHIC_LOW:
					addEventListener(Event.ENTER_FRAME, enterFrameLowGraphic);
					break;
					
				case GRAPHIC_HIGH:
					addEventListener(Event.ENTER_FRAME, enterFrameHighGraphic);
					break;
			}
			
			hideControls();
		}
		
		private function clearEnterFrame():void
		{
			switch(mGameGraphic)
			{
				case GRAPHIC_LOW:
					removeEventListener(Event.ENTER_FRAME, enterFrameLowGraphic);
					break;
					
				case GRAPHIC_HIGH:
					removeEventListener(Event.ENTER_FRAME, enterFrameHighGraphic);
					break;
			}
			
			showControls();
		}
		
		private function showControls():void
		{
			TweenMax.to(mControls, 1, {alpha:1});			
		}
		
		private function hideControls():void
		{
			TweenMax.to(mControls, 1, {alpha:0});
		}

		
		private function enterFrameLowGraphic(e:Event = null):void
		{			
			mPlayer1.x += mXDirectionPlayer1 * PLAYER_SPEED;
			mPlayer1.y += mYDirectionPlayer1 * PLAYER_SPEED;
		
			mPlayer2.x += mXDirectionPlayer2 * PLAYER_SPEED;
			mPlayer2.y += mYDirectionPlayer2 * PLAYER_SPEED;
			
			mBitmapDataCompare.fillRect(mClearRectangle, 0);
			
			mBitmapDataCompare.draw(mContainer);
			
			if(mBitmapData.hitTest(NULL_POINT, 1, mBitmapDataCompare, NULL_POINT) || mPlayer1.hitTestObject(mPlayer2) || playerOutOfRange())
				reset();
			else
				mBitmapData.draw(mContainer);								
		}
		
		private function enterFrameHighGraphic(e:Event = null):void
		{			
			mPlayer1.x += mXDirectionPlayer1 * PLAYER_SPEED;
			mPlayer1.y += mYDirectionPlayer1 * PLAYER_SPEED;
		
			mPlayer2.x += mXDirectionPlayer2 * PLAYER_SPEED;
			mPlayer2.y += mYDirectionPlayer2 * PLAYER_SPEED;
			
			mBitmapDataCompare.fillRect(mClearRectangle, 0);
			
			mBitmapDataCompare.draw(mContainer);
			
			if(mBitmapData.hitTest(NULL_POINT, 1, mBitmapDataCompare, NULL_POINT) || mPlayer1.hitTestObject(mPlayer2) || playerOutOfRange())
				reset();
			else
			{
				mBitmapData.draw(mContainer);
				
				mContainer.filters = [mDropShadow];				

				mBitmapDataBackground.draw(mContainer);
				mBitmapDataBackground.applyFilter(mBitmapDataBackground, mClearRectangle, NULL_POINT, mBlur);
								
				mContainer.filters = null;
			}									
		}
		
		private function playerOutOfRange():Boolean
		{
			mPlayerOut = false;
			
			if(mPlayer1.x < 0 || mPlayer2.x < 0)
				mPlayerOut = true;
			else if(mPlayer1.x > mGameWidth || mPlayer2.x > mGameWidth)
				mPlayerOut = true;
			else if(mPlayer1.y < 0 || mPlayer2.y < 0)
				mPlayerOut = true;	
			else if(mPlayer1.y > mGameHeight || mPlayer2.y > mGameHeight)
				mPlayerOut = true;
				
			return mPlayerOut;
		}
		
		private function reset():void
		{
			TweenMax.to(this, 2, {onComplete:restart});		
			clearEnterFrame();
			removeKeyboardEvents();
		}

		private function restart():void
		{
			initPlayerDirection();
			initPlayerPositions();
			
			clearBitmapData();
			clearBitmapDataBackground();
			
			addKeyboardEvents();
			
			initEnterFrame();
		}


		private function addChildren():void
		{
			addChild(mBitmapBackground);
			addChild(mBitmap);
			addChild(mControls);
		}
	}
}
