﻿package de.davidochmann.games.decypher 
{
	/**
	 * @author MR.WUT4
	 */
	
	import flash.events.KeyboardEvent;	
	import flash.display.Sprite;
	import flash.text.TextFormat;	
	import de.davidochmann.games.decypher.events.CharacterEvent;	
	import de.davidochmann.games.decypher.graphics.Character;	
	import de.davidochmann.games.decypher.interfaces.ICharacter;	
	import de.davidochmann.games.decypher.controls.Controls;	 	
	import de.davidochmann.games.decypher.events.ControlsEvent;	
	import de.davidochmann.games.decypher.level.LevelBuilder;	
		 
	public class DecypherMe extends Sprite 
	{
		private var mLevelBuilder:LevelBuilder;
		private var mGrid:CharacterGrid;
		private var mControls:Controls;

		
		public function DecypherMe()
		{
			initLevelBuilder();
			initControls();	
		}

		private function initLevelBuilder():void
		{
			var silentList:String	  = ",-!?'()^\"\§$%&/=`;# ";
			var characterList:String  = "ABCDEFGHIJKLMNOPQRSTUVWXYZÖÄÜß";
			var textFormat:TextFormat = new TextFormat("Verdana", 11, 0x010101);
			var elementWidth:uint	  = 13;
			var elementHeight:uint	  = 20;
			var elementSpace:uint	  = 1;
			var level:Sprite;
			
			var gridHeight:uint;
			var gridWidth:uint;
			var row:Array;
			var gridCharacter:ICharacter;
			
			mLevelBuilder = new LevelBuilder(stage, silentList, characterList, textFormat, elementWidth, elementHeight, elementSpace);
			mLevelBuilder.create(0);
			
			level = mLevelBuilder.container();
			
			level.x = 50;
			level.y = 50;
			
			mGrid = mLevelBuilder.getGridFactory().getCharacterGrid();
			gridHeight = mGrid.maxHeight();
						
			for(var i:uint = 0; i < gridHeight; i++)
			{
				row = mGrid.row(i);
				gridWidth = row.length;
				
				for(var j:uint = 0; j < gridWidth; j++)
				{
					gridCharacter = ICharacter(row[j]);
					if(gridCharacter is Character) Character(gridCharacter).addEventListener(CharacterEvent.UP,   characterEventUpHandler);
				}	
			}
			
			addChild(level);
		}
		
		private function characterEventUpHandler(e:CharacterEvent):void
		{
			var current:Character = Character(e.target);
			var selected:ICharacter;
			var gridHeight:uint = mGrid.maxHeight();
			var gridWidth:uint;
			var xposition:uint;
			var yposition:uint;
			var row:Array;
			
			for(var i:uint = 0; i < gridHeight; i++)
			{
				row = mGrid.row(i);
				gridWidth = row.length;
				
				for(var j:uint = 0; j < gridWidth; j++)
				{
					selected = ICharacter(row[j]);
					
					if(current == selected && selected is Character)
					{
						yposition = i;
						xposition = j;
						break;
					}					
				}		
			}

			mLevelBuilder.getGridNavigator().highlight(xposition, yposition);
			mGrid.highlightAll(current.getCharacter());									
		}
		
		
		private function initControls():void
		{
			mControls = Controls.getInstance();
			mControls.initialize(stage);
			
			mControls.getStage().addEventListener(KeyboardEvent.KEY_DOWN, keyboardKeyDownHandler);
			
			mControls.addEventListener(ControlsEvent.UP, controlsEventUpHandler);
			mControls.addEventListener(ControlsEvent.DOWN, controlsEventDownHandler);
			mControls.addEventListener(ControlsEvent.LEFT, controlsEventLeftHandler);
			mControls.addEventListener(ControlsEvent.RIGHT, controlsEventRightHandler);
			
			mControls.addEventListener(ControlsEvent.TAB, controlsEventTabHandler);
			mControls.addEventListener(ControlsEvent.ENTER, controlsEventTabHandler);
			mControls.addEventListener(ControlsEvent.ESCAPE, controlsEventTabHandler);
			mControls.addEventListener(ControlsEvent.SPACE, controlsEventTabHandler);
		}

		private function keyboardKeyDownHandler(e:KeyboardEvent):void
		{
			var keyCode:uint = e.keyCode;
			var newCharacter:String = StringConverter.capitalize(String.fromCharCode(e.charCode));
			var currentCharacter:String = mLevelBuilder.getGridNavigator().getActiveCharacter().getCharacter();
													
			mGrid.highlightAll(currentCharacter);

			if(keyCode != 38 && keyCode != 40 && keyCode != 37 && keyCode != 39 && keyCode != 32 && keyCode != 13 && keyCode != 27 && keyCode != 9)
				mLevelBuilder.getReplaceManager().replaceAll(currentCharacter, newCharacter);
		}

		private function controlsEventUpHandler(e:ControlsEvent):void
		{
			mLevelBuilder.getGridNavigator().highlightUp();
		}

		private function controlsEventDownHandler(e:ControlsEvent):void
		{
			mLevelBuilder.getGridNavigator().highlightDown();
		}
		
		private function controlsEventLeftHandler(e:ControlsEvent):void
		{
			mLevelBuilder.getGridNavigator().highlightLeft();
		}

		private function controlsEventRightHandler(e:ControlsEvent):void
		{
			mLevelBuilder.getGridNavigator().highlightRight();	
		}
		
		private function controlsEventTabHandler(e:ControlsEvent):void
		{
			mLevelBuilder.getGridNavigator().highlightNext();	
		}
		
	}		
}
