package de.davidochmann.games.decypher 
{
	/**
	 * @author dochmann
	 */

	import flash.errors.IllegalOperationError;	
	import de.davidochmann.games.decypher.graphics.Character;		
	import de.davidochmann.games.decypher.graphics.SilentCharacter;	
	import de.davidochmann.games.decypher.interfaces.ICharacter;	

	public class ReplaceManager 
	{
		private static var ALLOWED_CHARACTERS:String = "ABCDEFGHIJKLMNOPQRSTUVWXYZÖÄÜß";
		
		private var mGrid:Grid;
		
		private var mCurrentString:String;
		
		public function ReplaceManager(pGrid:Grid)
		{
			setGrid(pGrid);
		}
		
		
		public function currentString():String
		{
			return mCurrentString;
		}

		public function replaceAll(pCharacter:String, pNewCharacter:String):void
		{
			if(pCharacter == pNewCharacter)
				return;
			
			buildCurrentString();
			
			var contains:String = StringConverter.contains(mCurrentString);
			var isintext:int = contains.search(pNewCharacter);
			var previous:Array = new Array();			
			
			var height:uint = mGrid.maxHeight();
			var row:Array;
			var character:ICharacter;

			for(var i:uint = 0; i < height; i++)
			{
				row = mGrid.row(i);
				
				if(isintext != -1)
				{	
					for(var k:uint = 0; k < row.length; k++)
					{
						character = ICharacter(row[k]);
						
						if(character is Character && character.getCharacter() == pNewCharacter)
						{
							Character(character).text(pCharacter);
							previous.push(character);	
						}
					}
				}

				for(var j:uint = 0; j < row.length; j++)
				{
					character = ICharacter(row[j]);
										
					if(character is Character && character.getCharacter() == pCharacter && !inList(previous, character))
						Character(character).text(pNewCharacter);
				}

			}
		}

		public function replace(pXIndex:uint, pYIndex:uint, pCharacter:String):void
		{
			var character:ICharacter = ICharacter(mGrid.getElement(pXIndex, pYIndex));
			
			if(character is SilentCharacter)
				throw new IllegalOperationError("coordinates have to aim a character");
		
			if(pCharacter.length < 1 || pCharacter.length > 1)
				throw new IllegalOperationError("pCharacter has to have a length of one");
			
			if(! allowedCharacter(pCharacter))
				throw new IllegalOperationError("pCharacter has to be in the allowed characters list");
			
			Character(character).text(pCharacter);
		}

		public function buildCurrentString():void
		{
			var height:uint = mGrid.maxHeight();
			var row:Array;
			var text:String = "";
			var character:String;
			
			for(var i:uint = 0; i < height; i++)
			{
				row = mGrid.row(i);
				
				for(var j:uint = 0; j < row.length; j++)
				{
					character = ICharacter(row[j]).getCharacter();
					text += character;					
				}
			}
			
			mCurrentString = text;
		}

		
		public function getGrid():Grid
		{
			return mGrid;
		}

		
		public function setGrid(pGrid:Grid):void
		{
			mGrid = pGrid;
		}


		private function inList(pList:Array, pCharacter:ICharacter):Boolean
		{
			var inlist:Boolean = false;
			
			for(var i:uint = 0; i < pList.length; i++)
			{
				if(pList[i] == pCharacter)
				{
					inlist = true;
					break;				
				}
			}
			
			return inlist;
		}		
		
		private function allowedCharacter(pCharacter:String):Boolean
		{
			var current:String;
			var allowed:Boolean = false;
			
			for(var i:uint = 0; i < ALLOWED_CHARACTERS.length; i++)
			{
				current = ALLOWED_CHARACTERS.charAt(i);
				
				if(current == pCharacter)
				{
					allowed = true;
					break;					
				}								
			}
			
			return allowed;
		}
	}
}
