﻿package de.davidochmann.games.decypher.controls
{	
	/**
	 * @author David Ochmann
	 */

	import flash.errors.IllegalOperationError;		
	import de.davidochmann.games.decypher.Grid;	
	import de.davidochmann.games.decypher.CharacterGrid;	
	import de.davidochmann.games.decypher.graphics.SilentCharacter;		
	import de.davidochmann.games.decypher.interfaces.ICharacter;	

	public class GridNavigator 
	{
		private var mCharacterGrid:CharacterGrid;
		private var mActiveYIndex:uint;
		private var mActiveXIndex:uint;
		private var mActiveCharacter:ICharacter;
		

		public function GridNavigator(pCharacterGrid:CharacterGrid, pXIndex:uint, pYIndex:uint)
		{
			setCharacterGrid(pCharacterGrid);
			highlight(pXIndex, pYIndex);
		}
		
		
		public function highlight(pXIndex:uint, pYIndex:uint):void
		{
			if(mActiveCharacter != null && mActiveCharacter != SilentCharacter)
				mCharacterGrid.unlight(mActiveXIndex, mActiveYIndex);
			
			var character:ICharacter = mCharacterGrid.getCharacter(pXIndex, pYIndex); 
			
			if(character is SilentCharacter || character == null)
				throw new IllegalOperationError("character cannot be highlighted");
			
			mCharacterGrid.highlight(pXIndex, pYIndex);
			
			mActiveCharacter = character;
			mActiveXIndex = pXIndex;
			mActiveYIndex = pYIndex;
		}

		public function highlightUp():void
		{
			var activeY:uint = mActiveYIndex;
			var activeX:uint = mActiveXIndex;
			var maxHeight:uint = mCharacterGrid.maxHeight();
			var character:ICharacter;
			
			if(activeY == 0)
				activeY = maxHeight;
			else if(activeY > 0)
				activeY --;
			
			character = mCharacterGrid.getCharacter(activeX, activeY);
			
			while(character == null || character is SilentCharacter)
			{
				if(activeY == 0)
					activeY = maxHeight;
				else if(activeY > 0)
					activeY--;
				
				character = mCharacterGrid.getCharacter(activeX, activeY);
			}
			
			highlight(activeX, activeY);			
		}

		public function highlightDown():void
		{
			var activeY:uint = mActiveYIndex;
			var activeX:uint = mActiveXIndex;
			var maxHeight:uint = mCharacterGrid.maxHeight();
			var character:ICharacter;
			
			if(activeY == maxHeight)
				activeY = 0;
			else if(activeY < maxHeight)
				activeY ++;
			
			character = mCharacterGrid.getCharacter(activeX, activeY);
			
			while(character == null || character is SilentCharacter)
			{
				if(activeY == maxHeight)
					activeY = 0;
				else if(activeY < maxHeight)
					activeY ++;
				
				character = mCharacterGrid.getCharacter(activeX, activeY);
			}
			
			highlight(activeX, activeY);	
		}
		
		public function highlightLeft():void
		{
			var activeX:uint = mActiveXIndex;
			var activeY:uint = mActiveYIndex;
			var character:ICharacter;
			var rowLength:uint = mCharacterGrid.row(activeY).length - 1;	
			
			if(activeX == 0)
				activeX = rowLength;
			else if(activeX > 0)
				activeX --;
			
			character = mCharacterGrid.getCharacter(activeX, activeY);
			
			while(character == null || character is SilentCharacter)
			{
				if(activeX == 0)
					activeX = rowLength;
				else if(activeX > 0)
					activeX --;
				
				character = mCharacterGrid.getCharacter(activeX, activeY);
			}
			
			highlight(activeX, activeY);
		}
		
		public function highlightRight():void
		{
			var activeX:uint = mActiveXIndex;
			var activeY:uint = mActiveYIndex;
			var character:ICharacter;
			var rowLength:uint = mCharacterGrid.row(activeY).length - 1;
			
			if(activeX == rowLength)
				activeX = 0;
			else if(activeX < rowLength)
				activeX ++;
			
			character = mCharacterGrid.getCharacter(activeX, activeY);
			
			while(character == null || character is SilentCharacter)
			{
				if(activeX >= rowLength)
					activeX = 0;
				else if(activeX < rowLength)
					activeX ++;
				
				character = mCharacterGrid.getCharacter(activeX, activeY);
			}
			
			highlight(activeX, activeY);
		}

		public function highlightNext():void
		{
			var activeX:uint = mActiveXIndex;
			var activeY:uint = mActiveYIndex;
			var character:ICharacter;
			var rowLength:uint = mCharacterGrid.row(activeY).length;			
			var maxHeight:uint = mCharacterGrid.maxHeight();
										
			while(character == null || character is SilentCharacter)
			{
				activeX++;
				
				if(activeX >= rowLength && activeY >= maxHeight)
				{					
					activeX = 0;
					activeY = 0;	
				} 
				else if(activeX >= rowLength)
				{
					activeX = 0;
					activeY ++;
				}
								
				character = mCharacterGrid.getCharacter(activeX, activeY);
			}			

			character = mCharacterGrid.getCharacter(activeX, activeY);
			highlight(activeX, activeY);
		}
		
		public function highlightPrevious():void
		{
			var activeX:uint = mActiveXIndex;
			var activeY:uint = mActiveYIndex;
			var character:ICharacter;
			var maxHeight:uint = mCharacterGrid.maxHeight();
			var rowLength:uint = mCharacterGrid.row(activeY - 1).length - 1;			
			var lastLength:uint = mCharacterGrid.row(maxHeight - 1).length;

			if(activeX == 0 && activeY == 0)
			{
				activeY = maxHeight - 1;
				activeX = lastLength; 
			}
			else if(activeX == 0)
			{
				activeX = rowLength;
				activeY --;
			}
			else if(activeX > 0)
				activeX --;
						
			character = mCharacterGrid.getCharacter(activeX, activeY);
						
			while(character == null || character is SilentCharacter)
			{
				if(activeX == 0)
				{
					activeX = rowLength;
					activeY --;
				}
				else if(activeX > 0)
					activeX--;
				
				character = mCharacterGrid.getCharacter(activeX, activeY);
			}			
			
			highlight(activeX, activeY);
		}
		

		public function getActiveCharacter():ICharacter
		{
			return mActiveCharacter;
		}

		public function getActiveXIndex():uint
		{
			return mActiveXIndex;
		}

		public function getActiveYIndex():uint
		{
			return mActiveYIndex;
		}


		public function getGrid():Grid
		{
			return mCharacterGrid;
		}

		public function setCharacterGrid(pCharacterGrid:CharacterGrid):void
		{
			mCharacterGrid = pCharacterGrid;		
		}
	}
}
