﻿package de.davidochmann.games.decypher.graphics
{	
	/**
	 * @author MR.WUT4
	 */
	import flash.events.MouseEvent;	

	import de.davidochmann.games.decypher.interfaces.ICharacter;	 
	import de.davidochmann.games.decypher.events.CharacterEvent;	
	import flash.text.TextFieldAutoSize;		
	import flash.display.Graphics;	
	import flash.errors.IllegalOperationError;	
	import flash.text.TextField;	 
	import flash.text.TextFormat;	
	import flash.display.Sprite;
	
	public class Character extends Sprite implements ICharacter
	{
		private var mCharacter:String;
		private var mTextFormat:TextFormat;
		private var mWidth:uint;
		private var mHeight:uint;
		private var mHightlightColor:uint;
		private var mActive:Boolean;
		
		private var mBackground:Sprite;
		private var mTextField:TextField;
		private var mContainer:Sprite;
		
		
		public function Character(pCharacter:String, 
								  pTextFormat:TextFormat, 
							      pWidth:uint, 
								  pHeight:uint,
								  pHighlightColor:uint = 0xd00000,
								  pActive:Boolean = false)
		{
			setCharacter(pCharacter);
			setTextFormat(pTextFormat);
			setWidth(pWidth);
			setHeight(pHeight);
			setHighlightColor(pHighlightColor);
			setActive(pActive);
			
			initBackground();
			initTextField();
			initContainer();
			
			unlight();	
			update();
			
			initMouseEvents();
			
			addChildren();
		}
		
		
		public function text(pCharacter:String):void
		{
			setCharacter(pCharacter);
			mTextField.text = mCharacter;
			
			mTextField.x = mWidth  * .5 - mTextField.width  * .5;
			mTextField.y = mHeight * .5 - mTextField.height * .5;
		} 
		
		public function update():void
		{
			switch(mActive)
			{
				case true:
					dispatchEvent(new CharacterEvent(CharacterEvent.ACTIVE, mCharacter, true));
					active();
					break;
					
				case false:
					dispatchEvent(new CharacterEvent(CharacterEvent.INACTIVE, mCharacter, false));
					inactive();
					break;
			}
		}
		
		
		public function highlight():void
		{
			mBackground.alpha = 1;
		}

		public function unlight():void
		{
			mBackground.alpha = 0;
		}

		
		public function getCharacter():String
		{
			return mCharacter;	
		}

		public function getTextFormat():TextFormat
		{
			return mTextFormat;
		}

		public function getWidth():uint
		{
			return mWidth;
		}

		public function getHeight():uint
		{
			return mHeight;
		}

		public function getHighlightColor():uint
		{
			return mHightlightColor;
		}

		public function getActive():Boolean
		{
			return mActive;
		}

		
		public function setCharacter(pCharacter:String):void
		{
			if(pCharacter.length > 1 || pCharacter.length == 0)
				throw new IllegalOperationError("character must have a length of one");
			
			mCharacter = pCharacter;
		}
		
		public function setTextFormat(pTextFormat:TextFormat):void
		{
			mTextFormat = pTextFormat;
		}
		
		public function setWidth(pWidth:uint):void
		{
			mWidth = pWidth;
		}
		
		public function setHeight(pHeight:uint):void
		{
			mHeight = pHeight;
		}
		
		public function setHighlightColor(pHighlightColor:uint):void
		{
			mHightlightColor = pHighlightColor;
		}

		public function setActive(pActive:Boolean):void
		{
			mActive = pActive;
		}

		
		private function initBackground():void
		{
			mBackground = new Sprite();
			
			var canvas:Graphics = mBackground.graphics;
			
			canvas.beginFill(mHightlightColor, 1);
			canvas.drawRect(1, 1, mWidth - 2, mHeight - 2);
			canvas.endFill();			
		}

		private function initTextField():void
		{
			mTextField = new TextField();

			mTextField.defaultTextFormat = mTextFormat;
			mTextField.text = mCharacter;			
			
			mTextField.autoSize = TextFieldAutoSize.LEFT;
			mTextField.mouseEnabled = false;
			
			mTextField.x = mWidth  * .5 - mTextField.width  * .5;
			mTextField.y = mHeight * .5 - mTextField.height * .5;
		}

		private function initContainer():void
		{			
			mContainer = new Sprite();
			mContainer.addChild(mBackground);
			mContainer.addChild(mTextField);
		
			var canvas:Graphics = mContainer.graphics;
			
			canvas.beginFill(0x000000, 1);
					
			canvas.drawRect(1     	  , 0      	   , mWidth - 2, 1			);
			canvas.drawRect(1     	  , mHeight - 1, mWidth - 2, 1			);
			canvas.drawRect(mWidth - 1, 1      	   , 1         , mHeight - 2);
			canvas.drawRect(0     	  , 1      	   , 1         , mHeight - 2);

			canvas.endFill();
		}

		private function initMouseEvents():void
		{
			addEventListener(MouseEvent.MOUSE_UP, mouseUpHandler);
		}
		
		private function mouseUpHandler(e:MouseEvent):void
		{
			dispatchEvent(new CharacterEvent(CharacterEvent.UP, mCharacter, true));	
		}

		private function active():void
		{
			alpha = 1;
		}
		
		private function inactive():void
		{
			alpha = .4;
		}

		
		private function addChildren():void
		{
			addChild(mContainer);
		}
	}
}
