package de.davidochmann.games.decypher.graphics 
{	
	/**
	 * @author MR.WUT4
	 */
	 
	import de.davidochmann.games.decypher.Validate;	
	import flash.display.Graphics;	
	import flash.display.Sprite;
	 
	public class ContentBubble extends Sprite 
	{
		public static var ARRANGE_TOP:uint = 0;
		public static var ARRANGE_BOTTOM:uint = 1;
		
		private var mContent:Sprite;
		private var mWidth:uint;
		private var mHeight:uint;
		private var mColor:uint;
		private var mAlpha:Number;
		
		private var mArrow:Sprite;
		private var mMask:Sprite;
		private var mBackground:Sprite;
		private var mBubbleContainer:Sprite;
		
		
		public function ContentBubble(pContent:Sprite, 
									  pWidth:uint, 
									  pHeight:uint, 
									  pColor:uint = 0xfffff,
									  pAlpha:Number = 1)
		{
			
			setContent(pContent);
			setWidth(pWidth);
			setHeight(pHeight);
			setColor(pColor);
			setAlpha(pAlpha);
			
			initMask();
			initArrow();
			initBackground();
			initBubbleContainer();
			
			update(0, ARRANGE_TOP);

			addChildren();
		}
		
		
		public function update(pMouseX:uint, pArrangement:uint):void
		{
			switch(pArrangement)
			{
				case ARRANGE_TOP:
					mBackground.y = - mHeight - mArrow.height + 5;
					mContent.y = - mHeight - mArrow.height + 5;
					
					mArrow.y = - mArrow.height;
					mMask.y = mBackground.y + mArrow.height - 5;
					
					mArrow.x = uint(Validate.minMaxValue(0, mWidth - mArrow.width, pMouseX));				
					break;
					
				case ARRANGE_BOTTOM:
					mArrow.scaleY = -1;
					mMask.scaleY = -1;
					
					mArrow.y = mArrow.height;
					mMask.y = mBackground.height ;
									
					mBackground.y = mArrow.height - 5;
					mContent.y = mArrow.height - 5;
					
					mArrow.x = uint(Validate.minMaxValue(0, mWidth - mArrow.width, pMouseX));	
					break;
			}	
		}
		
		
		public function getContent():Sprite
		{
			return mContent;
		}

		public function getWidth():uint
		{
			return mWidth;
		}

		public function getHeight():uint
		{
			return mHeight;
		}

		public function getColor():uint
		{
			return mColor;
		}

		public function getAlpha():Number
		{
			return mAlpha;
		}

		
		public function setContent(pContent:Sprite):void
		{
			mContent = pContent;
		}
		
		public function setWidth(pWidth:uint):void
		{
			mWidth = pWidth;
		}
		
		public function setHeight(pHeight:uint):void
		{
			mHeight = pHeight;
		}
		
		public function setColor(pColor:uint):void
		{
			mColor = pColor;
		}

		public function setAlpha(pAlpha:Number):void
		{
			mAlpha = pAlpha;
		}
		
		
		private function initMask():void
		{
			mMask = new Sprite();
			
			var canvas:Graphics = mMask.graphics;
			
			canvas.beginFill(0x00ff00);
			canvas.drawRoundRect(0, 0, mWidth, mHeight     , 10, 10);
			canvas.drawRoundRect(0, 0, mWidth, mHeight - 15, 10, 10);
			canvas.endFill();
			
			mMask.cacheAsBitmap = true;
		}

		private function initArrow():void
		{
			mArrow = new Sprite();
			
			var canvas:Graphics = mArrow.graphics;
			
			canvas.beginFill(mColor, mAlpha);

			canvas.lineTo(15, 0 );
			canvas.lineTo(0 , 20);
			canvas.lineTo(0 , 0 );
			
			canvas.endFill();	
			
			mArrow.cacheAsBitmap = true;

			mArrow.mask = mMask;
		}

		private function initBackground():void
		{
			mBackground = new Sprite();
			
			var canvas:Graphics = mBackground.graphics;
					
			canvas.beginFill(mColor, mAlpha);
			canvas.drawRoundRect(0, 0, mWidth, mHeight, 10, 10);
			canvas.endFill();
		}

		private function initBubbleContainer():void
		{
			mBubbleContainer = new Sprite();
			
			mBubbleContainer.addChild(mMask);			
			mBubbleContainer.addChild(mArrow);
			mBubbleContainer.addChild(mBackground);
			mBubbleContainer.addChild(mContent);
		}
		
		
		private function addChildren():void
		{
			addChild(mBubbleContainer);
		}
	}
}
