﻿package de.davidochmann.games.decypher.graphics
{
	import flash.text.TextFormat;	
	import flash.display.Sprite;	
	import de.davidochmann.games.decypher.CharacterGrid;	
	import de.davidochmann.games.decypher.StringConverter;	
	import de.davidochmann.games.decypher.graphics.SilentCharacter;		
	import de.davidochmann.games.decypher.graphics.Character;	
	import de.davidochmann.games.decypher.graphics.GridCreator;	
	import de.davidochmann.games.decypher.interfaces.ICharacter;	
	
	/**
	 * @author David Ochmann
	 */

	public class GridFactory 
	{
		private var mText:String;
		private var mSilentList:String;
		private var mElementHeight:uint;
		private var mElementWidth:uint;
		private var mElementSpace:uint;
		private var mTextFormat:TextFormat;

		private var mContainer:Sprite;
		private var mCharacterGrid:CharacterGrid;
		private var mGridCreator:GridCreator;


		public function GridFactory(pText:String, 
									pSilentList:String, 
									pTextFormat:TextFormat, 
									pElementWidth:uint, 
									pElementHeight:uint, 
									pElementSpace:uint)
		{
			setText(pText);
			setSilentList(pSilentList);
			setElementWidth(pElementWidth);
			setElementHeight(pElementHeight);
			setElementSpace(pElementSpace);
			setTextFormat(pTextFormat);

			initChracterGrid();
			initGridCreator();
		}


		public function clear():void
		{
			mContainer = null;
		}


		public function create():Sprite
		{
//			var splitArray:Array = StringConverter.split(StringConverter.capitalize(mText));
			var splitArray:Array = StringConverter.split(mText);
			
			var char:String;
			var breakString:String;
			var xIndex:Number;
			var yIndex:Number;
			var character:ICharacter;			
			
			for(var i:uint = 0; i < splitArray.length; i++)
			{
				breakString = splitArray[i];
				yIndex = i;
								
				for(var j:uint = 0; j < breakString.length; j++)
				{
					xIndex = j;
					char = breakString.charAt(j);
					
					if(checkSilenList(char))
						character = new SilentCharacter(char, mTextFormat, mElementWidth, mElementHeight);
					else
						character = new Character(char, mTextFormat, mElementWidth, mElementHeight, 0xdd0000, false);
										
					mCharacterGrid.setCharacter(xIndex, yIndex, character);
				}
			}
			
			mContainer = mGridCreator.create();
			
			return mContainer;	
		}

		public function getCharacterGrid():CharacterGrid
		{
			return mCharacterGrid;
		}

		public function getGridCreator():GridCreator
		{
			return mGridCreator;
		}

		
		public function getText():String
		{
			return mText;
		}
		
		public function getSilentList():String
		{
			return mSilentList;
		}

		public function getTextFormat():TextFormat
		{
			return mTextFormat;
		}

		public function getElementWidth():uint
		{
			return mElementWidth;
		}

		public function getElementHeight():uint
		{
			return mElementHeight;
		}
		
		public function getElementSpace():uint
		{
			return mElementSpace;
		}


		public function setText(pText:String):void
		{
			mText = pText;
		}

		public function setSilentList(pSilentList:String):void
		{
			mSilentList = pSilentList;
		}

		public function setTextFormat(pTextFormat:TextFormat):void
		{
			mTextFormat = pTextFormat;
		}

		public function setElementWidth(pElementWidth:uint):void
		{
			mElementWidth = pElementWidth;
		}

		public function setElementHeight(pElementHeight:uint):void
		{
			mElementHeight = pElementHeight;
		}
	
		public function setElementSpace(pElementSpace:uint):void
		{
			mElementSpace = pElementSpace;
		}

		
		private function initChracterGrid():void
		{
			mCharacterGrid = new CharacterGrid();
		}

		private function initGridCreator():void
		{
			mGridCreator = new GridCreator(mCharacterGrid, mElementWidth, mElementHeight, mElementSpace);
		}
		
		
		private function checkSilenList(pCharacter:String):Boolean
		{
			var char:String;
			var inList:Boolean = false;
			
			for(var i:uint = 0; i < mSilentList.length; i++)
			{
				char = mSilentList.charAt(i);
				
				if(char == pCharacter)
				{
					inList = true;
					break;
				}
			}
			
			return inList;
		}
	}
}
