﻿package de.davidochmann.games.decypher.level
{
	/**
	 * @author dochmann
	 */
	 
	import flash.geom.Point;	
	import flash.display.Sprite;	
	import flash.display.Stage;	
	import flash.text.TextFormat;
	import de.davidochmann.games.decypher.ReplaceManager;
	import de.davidochmann.games.decypher.StringConverter;	
	import de.davidochmann.games.decypher.controls.GridNavigator;	
	import de.davidochmann.games.decypher.CharacterGrid;
	import de.davidochmann.games.decypher.graphics.GridFactory;	
	
	public class LevelBuilder 
	{ 
		private var mStage:Stage;
		private var mSilentList:String;
		private var mCharacterList:String;
		private var mTextFormat:TextFormat;
		private var mElementWidth:uint;
		private var mElementHeight:uint;
		private var mElementSpace:uint;
		private var mLevelContainer:LevelContainer;
		private var mGridFactory:GridFactory;
		private var mGridNavigator:GridNavigator;
		private var mReplaceManager:ReplaceManager;
		private var mContainer:Sprite;


		public function LevelBuilder(pStage:Stage,
									 pSilentList:String,
									 pCharacterList:String,
									 pTextFormat:TextFormat,
									 pElementWidth:uint,
									 pElementHeight:uint,
									 pElementSpace:uint)
		{
			setStage(pStage);
			setSilentList(pSilentList);
			setCharacterList(pCharacterList);	
			setTextFormat(pTextFormat);
			setElementWidth(pElementWidth);
			setElementHeight(pElementHeight);
			setElementSpace(pElementSpace);
			
			initLevelContainer();
		}
		
		
		public function create(pLevel:uint):void
		{
			var text:String = StringConverter.capitalize(mLevelContainer.level(pLevel)); 
			var cypheredText:String = StringConverter.shuffle(text, mCharacterList, mSilentList);
			var highlight:Point = new Point(0, 0);
			var grid:CharacterGrid;
			var character:String;
		
			mGridFactory = new GridFactory(cypheredText, mSilentList, mTextFormat, mElementWidth, mElementHeight, mElementSpace);
			mContainer = mGridFactory.create();
			
			grid = mGridFactory.getCharacterGrid();
			character = grid.getCharacter(highlight.x, highlight.y).getCharacter();
			
			mGridNavigator = new GridNavigator(grid, highlight.x, highlight.y);
			mReplaceManager = new ReplaceManager(grid);

			grid.highlightAll(character);
		}

		public function container():Sprite
		{
			return mContainer;
		}

		public function clear():void
		{}
		
		
		public function getGridFactory():GridFactory
		{		
			return mGridFactory;
		}
	
		public function getGridNavigator():GridNavigator
		{				
			return mGridNavigator;
		}

		public function getReplaceManager():ReplaceManager
		{
			return mReplaceManager;
		}

		
		public function getStage():Stage
		{
			return mStage;
		}
		
		public function getSilentList():String
		{
			return mSilentList;
		}

		public function getCharacterList():String
		{
			return mCharacterList;
		}

		public function getTextFormat():TextFormat
		{
			return mTextFormat;
		}

		public function getElementWidth():uint
		{
			return mElementWidth;
		}

		public function getElementHeight():uint
		{
			return mElementHeight;
		}
		
		public function getElementSpace():uint
		{
			return mElementSpace;
		}
		
		
		public function setStage(pStage:Stage):void
		{
			mStage = pStage;
		}

		public function setSilentList(pSilentList:String):void
		{
			mSilentList = pSilentList;
		}

		public function setCharacterList(pCharacterList:String):void
		{
			mCharacterList = pCharacterList;
		}

		public function setTextFormat(pTextFormat:TextFormat):void
		{
			mTextFormat = pTextFormat;
		}

		public function setElementWidth(pElementWidth:uint):void
		{
			mElementWidth = pElementWidth;
		}

		public function setElementHeight(pElementHeight:uint):void
		{
			mElementHeight = pElementHeight;
		}
	
		public function setElementSpace(pElementSpace:uint):void
		{
			mElementSpace = pElementSpace;
		}

		
		private function initLevelContainer():void
		{
			mLevelContainer = new LevelContainer();	
		}
	}
}
